@@ -1,4 +1,4 @@
-# $Id: Memcached.pm,v 1.1 2003/10/26 03:00:53 bradfitz Exp $
+# $Id: Memcached.pm,v 1.2 2003/10/26 09:04:36 bradfitz Exp $
 #
 # Copyright (c) 2003  Brad Fitzpatrick <brad@danga.com>
 #
@@ -15,6 +15,9 @@ use IO::Handle ();
 
 BEGIN {
     eval "use Time::HiRes qw (alarm);";
+
+    # so it'll bomb during tests on Solaris, until we make it work
+    $_ = MSG_NOSIGNAL;
 }
 
 # flag definitions
@@ -25,7 +28,7 @@ use constant F_COMPRESS => 2;
 use constant COMPRESS_SAVINGS => 0.20; # percent
 
 use vars qw($VERSION $HAVE_ZLIB);
-$VERSION = "1.0.10";
+$VERSION = "1.0.11";
 
 BEGIN {
     $HAVE_ZLIB = eval "use Compress::Zlib (); 1;";
